@@ -735,7 +735,7 @@ void opendal_operator_free(const struct opendal_operator *ptr);
  * reference the [documentation](https://opendal.apache.org/docs/category/services/) for
  * each service, especially for the **Configuration Part**.
  *
- * @param scheme the service scheme you want to specify, e.g. "fs", "s3", "supabase"
+ * @param scheme the service scheme you want to specify, e.g. "fs", "s3"
  * @param options the pointer to the options for this operator, it could be NULL, which means no
  * option is set
  * @see opendal_operator_options
@@ -1300,6 +1300,8 @@ struct opendal_error *opendal_operator_copy(const struct opendal_operator *op,
                                             const char *src,
                                             const char *dest);
 
+struct opendal_error *opendal_operator_check(const struct opendal_operator *op);
+
 /**
  * \brief Get information of underlying accessor.
  *
